@@ -63,7 +63,7 @@ class Query:
     datasets: Optional[List[From]] = None
     where: Optional[List[Condition]] = None
     orderBy: Optional[List[Sorting]] = None
-    limit: Optional[int] = None
+    limit: Optional[Union[int, str]] = None
 
     def to_sql(self, dataset: str = None):
         sql = "SELECT {} FROM {}"
@@ -95,7 +95,14 @@ class Query:
             sql_where = " WHERE {}"
 
             for condition in self.where:
-                formatted_value = "( " + ", ".join(condition.value) + " )"
+                vars = []
+                for var in condition.value:
+                    var = str(var)
+                    if var.isnumeric():
+                        vars.append(var)
+                    else:
+                        vars.append(var)
+                formatted_value = "( " + ", ".join(vars) + " )"
                 if isinstance(condition.operator, str):
                     operator = condition.operator
                 else:
